@@ -6,7 +6,18 @@ package POE::Loop::EV;
 use strict;
 use POE::Loop::PerlSignals;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
+
+=for poe_tests
+sub skip_tests {
+    return "EV tests require the EV module" if (
+        do { eval "use EV"; $@ }
+    );
+    return "wheel_readwrite test disabled for kqueue"
+        if EV::backend() == EV::BACKEND_KQUEUE() && $_[0] eq 'wheel_readwrite';
+}
+
+=cut
 
 # Everything plugs into POE::Kernel.
 package # hide me from PAUSE
@@ -277,6 +288,9 @@ Certain EV backends do not support polling on normal filehandles, namely
 epoll and kqueue.  You should avoid using regular filehandles with select_read,
 select_write, ReadWrite, etc.
 
+See the L<libev documentation|http://pod.tst.eu/http://cvs.schmorp.de/libev/ev.pod#PORTABILITY_NOTES>
+for more information on portability issues with different EV backends.
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Loop>, L<EV>
